emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/src/emacs.c,v


From: Glenn Morris
Subject: [Emacs-diffs] Changes to emacs/src/emacs.c,v
Date: Thu, 13 Mar 2008 03:03:56 +0000

CVSROOT:        /sources/emacs
Module name:    emacs
Changes by:     Glenn Morris <gm>       08/03/13 03:03:55

Index: emacs.c
===================================================================
RCS file: /sources/emacs/emacs/src/emacs.c,v
retrieving revision 1.419
retrieving revision 1.420
diff -u -b -r1.419 -r1.420
--- emacs.c     27 Feb 2008 04:58:42 -0000      1.419
+++ emacs.c     13 Mar 2008 03:03:55 -0000      1.420
@@ -1133,9 +1133,10 @@
   if (argmatch (argv, argc, "-script", "--script", 3, &junk, &skip_args))
     {
       noninteractive = 1;      /* Set batch mode.  */
       /* Convert --script to --scriptload, un-skip it, and sort again
         so that it will be handled in proper sequence.  */
-      argv[skip_args - 1] = "-scriptload";
+      /* FIXME broken for --script=FILE - is that supposed to work?  */
+      argv[skip_args - 1] = "-internal-script";
       skip_args -= 2;
       sort_args (argc, argv);
     }
@@ -1427,11 +1428,7 @@
 
 #ifdef USE_FONT_BACKEND
   enable_font_backend = 1;
-  if (argmatch (argv, argc, "-enable-font-backend", "--enable-font-backend",
-               4, NULL, &skip_args))
-    enable_font_backend = 1;
-  else if (argmatch (argv, argc,
-                    "-disable-font-backend", "--disable-font-backend",
+  if (argmatch (argv, argc, "-disable-font-backend", "--disable-font-backend",
                     4, NULL, &skip_args))
     enable_font_backend = 0;
 #endif /* USE_FONT_BACKEND */
@@ -1822,7 +1819,6 @@
   { "-unibyte", "--unibyte", 81, 0 },
   { "-no-multibyte", "--no-multibyte", 80, 0 },
   { "-nl", "--no-loadup", 70, 0 },
-  { "-enable-font-backend", "--enable-font-backend", 65, 0 },
   { "-disable-font-backend", "--disable-font-backend", 65, 0 },
   /* -d must come last before the options handled in startup.el.  */
   { "-d", "--display", 60, 1 },
@@ -1876,7 +1872,11 @@
   { "-directory", 0, 0, 1 },
   { "-l", "--load", 0, 1 },
   { "-load", 0, 0, 1 },
-  { "-scriptload", "--scriptload", 0, 1 },
+  /* This was --scriptload, but that confuses sort_args, because then
+     the --script long option seems to match twice; ie you can't have
+     a long option which is a prefix of another long option.
+     In any case, this is entirely an internal option.  */
+  { "-internal-script", "--internal-script", 0, 1 },
   { "-f", "--funcall", 0, 1 },
   { "-funcall", 0, 0, 1 },
   { "-eval", "--eval", 0, 1 },
@@ -1987,6 +1987,9 @@
                    fatal ("Option `%s' requires an argument\n", argv[from]);
                  from += options[from];
                }
+             /* FIXME When match < 0, shouldn't there be some error,
+                or at least indication to the user that there was a
+                problem?  */
            }
        done: ;
        }
@@ -1133,9 +1133,10 @@
     {
       noninteractive = 1;      /* Set batch mode.  */
-      /* Convert --script to --scriptload, un-skip it, and sort again
+      /* Convert --script to -internal-script, un-skip it, and sort again
         so that it will be handled in proper sequence.  */




reply via email to

[Prev in Thread] Current Thread [Next in Thread]